==> download.php?FileName=terralib-5.4.0.zip: share/terralib/translations/terralib_mod_qt_plugins_datasource_pgis_pt_br.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>PostGISConnectorDialogForm</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="26"/>
        <source>PostGIS Connector</source>
        <translation>Conector PostGIS</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="56"/>
        <source>PostGIS</source>
        <translation>PostGIS</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="76"/>
        <source>Base Information</source>
        <translation>Informações Básicas</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="84"/>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="98"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="132"/>
        <source>Connection Information</source>
        <translation>Informações de Conexão</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="150"/>
        <source>Host</source>
        <translation>Servidor</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="171"/>
        <source>User</source>
        <translation>Usuário</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="192"/>
        <source>Database Name</source>
        <translation>Nome do Banco de Dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="233"/>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="277"/>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
    <message>
        <source>Client Encoding</source>
        <translation type="vanished">Codificação do Cliente</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="306"/>
        <source>Save Password</source>
        <translation>Salvar Senha</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="325"/>
        <source>Advanced Connection Options</source>
        <translation>Opções de Conexão Avançadas</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="346"/>
        <source>Advanced Options</source>
        <translation>Opções Avançadas</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="384"/>
        <source>Tables</source>
        <translation>Tabelas</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="394"/>
        <source>Tables to be hidden</source>
        <translation>Tabelas a serem ocultadas</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="406"/>
        <source>Hide spatial metadata tables</source>
        <translation>Ocultar tabelas de metadados espaciais</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="413"/>
        <source>Hide raster tables</source>
        <translation>Ocultar tabelas matriciais (raster)</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="427"/>
        <source>Connect timeout</source>
        <translation>Tempo limite de conexão (timeout)</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="463"/>
        <source>Connection Pooling</source>
        <translation>Pool de Conexão</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="473"/>
        <source>Max</source>
        <translation>Máximo</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="497"/>
        <source>Min</source>
        <translation>Mínimo</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="521"/>
        <source>Max Idle Time</source>
        <translation>Tempo Max Idle</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="560"/>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="605"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="627"/>
        <source>&amp;Test</source>
        <translation>&amp;Teste</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="634"/>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="641"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
</context>
<context>
    <name>PostGISCreatorDialogForm</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="14"/>
        <source>PostGIS Creator</source>
        <translation>Criador PostGIS</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="50"/>
        <source>PostGIS</source>
        <translation>PostGIS</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="64"/>
        <source>Server Information</source>
        <translation>Informações do Servidor</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="78"/>
        <source>Host Name/IP</source>
        <translation>Nome do Servidor/IP</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="99"/>
        <source>User</source>
        <translation>Usuário</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="126"/>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="171"/>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="197"/>
        <source>Save Password</source>
        <translation>Salvar Senha</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="212"/>
        <source>Creation Information</source>
        <translation>Informações de Criação</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="226"/>
        <source>New Database Name</source>
        <translation>Nome do Novo Banco de Dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="240"/>
        <source>Database Template</source>
        <translation>Template do Banco de Dados</translation>
    </message>
    <message>
        <source>PostGIS Template</source>
        <translation type="vanished">Template PostGIS</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="265"/>
        <source>Advanced Creation options</source>
        <translation>Opções de Criação Avançada</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="274"/>
        <source>Advanced Creation Options</source>
        <translation>Opções de Criação Avançadas</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="349"/>
        <source>Owner</source>
        <translation>Proprietário</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="291"/>
        <source>No limit connections</source>
        <translation>Num. limite de conecções</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="335"/>
        <source>Tablespace</source>
        <translation>Tablespace</translation>
    </message>
    <message>
        <source>Encoding</source>
        <translation type="vanished">Codificação</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="394"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="416"/>
        <source>&amp;Apply</source>
        <translation>&amp;Aplicar</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="423"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::pgis::PostGISConnectorDialog</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/PostGISConnectorDialog.cpp" line="147"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/PostGISConnectorDialog.cpp" line="154"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/PostGISConnectorDialog.cpp" line="178"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/PostGISConnectorDialog.cpp" line="186"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/PostGISConnectorDialog.cpp" line="192"/>
        <source>TerraLib Qt Components</source>
        <translation>Componentes TerraLib Qt</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/PostGISConnectorDialog.cpp" line="155"/>
        <source>Unknown error while opening PostgreSQL database!</source>
        <translation>Erro desconhecido ao abrir banco de dados PostgreSQL !</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/PostGISConnectorDialog.cpp" line="179"/>
        <source>Data source is ok!</source>
        <translation>Fonte de dados está ok !</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/PostGISConnectorDialog.cpp" line="193"/>
        <source>Unknown error while testing PostgreSQL + PostGIS data source!</source>
        <translation>Erro desconhecido durante teste da fonte de dados PostgreSQL + PostGIS !</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::pgis::PostGISCreatorDialog</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/PostGISCreatorDialog.cpp" line="154"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/PostGISCreatorDialog.cpp" line="162"/>
        <source>TerraLib Qt Components</source>
        <translation>Componentes TerraLib Qt</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/PostGISCreatorDialog.cpp" line="163"/>
        <source>Unknown error while opening PostgreSQL database!</source>
        <translation>Erro desconhecido ao abrir banco de dados PostgreSQL !</translation>
    </message>
</context>
</TS>

==> download.php?FileName=terralib-5.5.0.zip: share/terralib/translations/terralib_mod_qt_plugins_datasource_pgis_pt_br.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<context>
    <name>PostGISConnectorDialogForm</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="26"/>
        <source>PostGIS Connector</source>
        <translation>Conector PostGIS</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="56"/>
        <source>PostGIS</source>
        <translation>PostGIS</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="76"/>
        <source>Base Information</source>
        <translation>Informações Básicas</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="84"/>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="98"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="132"/>
        <source>Connection Information</source>
        <translation>Informações de Conexão</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="150"/>
        <source>Host</source>
        <translation>Servidor</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="171"/>
        <source>User</source>
        <translation>Usuário</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="192"/>
        <source>Database Name</source>
        <translation>Nome do Banco de Dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="233"/>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="277"/>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
    <message>
        <source>Client Encoding</source>
        <translation type="obsolete">Codificação do Cliente</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="306"/>
        <source>Save Password</source>
        <translation>Salvar Senha</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="325"/>
        <source>Advanced Connection Options</source>
        <translation>Opções de Conexão Avançadas</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="346"/>
        <source>Advanced Options</source>
        <translation>Opções Avançadas</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="384"/>
        <source>Tables</source>
        <translation>Tabelas</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="394"/>
        <source>Tables to be hidden</source>
        <translation>Tabelas a serem ocultadas</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="406"/>
        <source>Hide spatial metadata tables</source>
        <translation>Ocultar tabelas de metadados espaciais</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="413"/>
        <source>Hide raster tables</source>
        <translation>Ocultar tabelas matriciais (raster)</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="427"/>
        <source>Connect timeout</source>
        <translation>Tempo limite de conexão (timeout)</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="463"/>
        <source>Connection Pooling</source>
        <translation>Pool de Conexão</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="473"/>
        <source>Max</source>
        <translation>Máximo</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="497"/>
        <source>Min</source>
        <translation>Mínimo</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="521"/>
        <source>Max Idle Time</source>
        <translation>Tempo Max Idle</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="560"/>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="585"/>
        <source>SSL Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="615"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="637"/>
        <source>&amp;Test</source>
        <translation>&amp;Teste</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="644"/>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISConnectorDialogForm.ui" line="651"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
</context>
<context>
    <name>PostGISCreatorDialogForm</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="14"/>
        <source>PostGIS Creator</source>
        <translation>Criador PostGIS</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="50"/>
        <source>PostGIS</source>
        <translation>PostGIS</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="64"/>
        <source>Server Information</source>
        <translation>Informações do Servidor</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="78"/>
        <source>Host Name/IP</source>
        <translation>Nome do Servidor/IP</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="99"/>
        <source>User</source>
        <translation>Usuário</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="126"/>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="171"/>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="197"/>
        <source>Save Password</source>
        <translation>Salvar Senha</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="212"/>
        <source>Creation Information</source>
        <translation>Informações de Criação</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="226"/>
        <source>New Database Name</source>
        <translation>Nome do Novo Banco de Dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="240"/>
        <source>Database Template</source>
        <translation>Template do Banco de Dados</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="381"/>
        <source>SSL Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PostGIS Template</source>
        <translation type="obsolete">Template PostGIS</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="265"/>
        <source>Advanced Creation options</source>
        <translation>Opções de Criação Avançada</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="274"/>
        <source>Advanced Creation Options</source>
        <translation>Opções de Criação Avançadas</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="307"/>
        <source>Owner</source>
        <translation>Proprietário</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="323"/>
        <source>No limit connections</source>
        <translation>Num. limite de conecções</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="293"/>
        <source>Tablespace</source>
        <translation>Tablespace</translation>
    </message>
    <message>
        <source>Encoding</source>
        <translation type="obsolete">Codificação</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="404"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="426"/>
        <source>&amp;Apply</source>
        <translation>&amp;Aplicar</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/ui/PostGISCreatorDialogForm.ui" line="433"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::pgis::PostGISConnectorDialog</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/PostGISConnectorDialog.cpp" line="155"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/PostGISConnectorDialog.cpp" line="162"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/PostGISConnectorDialog.cpp" line="186"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/PostGISConnectorDialog.cpp" line="194"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/PostGISConnectorDialog.cpp" line="200"/>
        <source>TerraLib Qt Components</source>
        <translation>Componentes TerraLib Qt</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/PostGISConnectorDialog.cpp" line="163"/>
        <source>Unknown error while opening PostgreSQL database!</source>
        <translation>Erro desconhecido ao abrir banco de dados PostgreSQL !</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/PostGISConnectorDialog.cpp" line="187"/>
        <source>Data source is ok!</source>
        <translation>Fonte de dados está ok !</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/PostGISConnectorDialog.cpp" line="201"/>
        <source>Unknown error while testing PostgreSQL + PostGIS data source!</source>
        <translation>Erro desconhecido durante teste da fonte de dados PostgreSQL + PostGIS !</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::pgis::PostGISCreatorDialog</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/PostGISCreatorDialog.cpp" line="162"/>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/PostGISCreatorDialog.cpp" line="170"/>
        <source>TerraLib Qt Components</source>
        <translation>Componentes TerraLib Qt</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/datasource/pgis/PostGISCreatorDialog.cpp" line="171"/>
        <source>Unknown error while opening PostgreSQL database!</source>
        <translation>Erro desconhecido ao abrir banco de dados PostgreSQL !</translation>
    </message>
</context>
</TS>
